import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// defines the Colors for Pie Chart different sections
const sectionColors = [
  		'yellow', 'orange', 'lightgreen', 'pink', 'red', 'yellow', 'purple', 'brown', 'navyblue', 'violet'
		  ];

// link or URL of my dataset which is different countries accidentrate
const csvUrl = 'https://gist.githubusercontent.com/Tulluripallavi/052663630be413f68e881bb1d64f22fc/raw/9f3679b8452c90389f9413d5ac7dfba60fd652d3/Song.csv';

// Function to get or retrive the data from the URL
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

//text of Format axes
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// These are used to render Pie Chart 
const render = (data, total) => {
  const pieData = pie().value(d=>d.CONTRIBUTION)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  // used for generating Arcs of the different sections
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.CONTRIBUTION));
  

  
  // Render legend for the data that we had given
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.CONTRIBUTION));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.PERSON);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.CONTRIBUTION/1))+"%");
}

// Main function
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.CONTRIBUTION = +d.CONTRIBUTION;
    total += d.CONTRIBUTION
  });
	render(data,total);
};
run();